@@ -54,24 +54,21 @@ func Test_Feed(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 	err = os.WriteFile(path.Join(listsDir, "test"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -134,6 +131,170 @@ RSS Feed        • Item 1
 	assert.Equal(t, atom, string(b))
 }
 
+func Test_Feed_CachedOnly(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	timeMock := mocks.NewMockTime(ctrl)
+	timeMock.EXPECT().Now().Return(defaultCurrentTime).AnyTimes()
+
+	out := new(bytes.Buffer)
+	printer := internal.NewPrinter(nil, out, out)
+	storage := _storage.NewLocalStorage("cleed_test", timeMock)
+	defer localStorageCleanup(t, storage)
+
+	configDir, err := os.UserConfigDir()
+	if err != nil {
+		t.Fatal(err)
+	}
+	listsDir := path.Join(configDir, "cleed_test", "lists")
+	err = os.MkdirAll(listsDir, 0700)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	rss := createDefaultRSS()
+	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		if r.URL.Path == "/rss" {
+			w.Header().Set("ETag", "123")
+			w.Write([]byte(rss))
+		}
+	}))
+	defer server.Close()
+
+	err = os.WriteFile(path.Join(listsDir, "default"),
+		fmt.Appendf(nil, "%d %s\n",
+			defaultCurrentTime.Unix(), server.URL+"/rss",
+		), 0600)
+	if err != nil {
+		t.Fatal(err)
+	}
+	err = os.WriteFile(path.Join(listsDir, "test"),
+		fmt.Appendf(nil, "%d %s\n",
+			defaultCurrentTime.Unix(), server.URL+"/atom",
+		), 0600)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	cacheDir, err := os.UserCacheDir()
+	if err != nil {
+		t.Fatal(err)
+	}
+	cacheDir = path.Join(cacheDir, "cleed_test")
+	err = os.MkdirAll(cacheDir, 0700)
+	if err != nil {
+		t.Fatal(err)
+	}
+	atom := createDefaultAtom()
+	err = storage.SaveFeedCache(bytes.NewBufferString(atom), server.URL+"/atom")
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	storage.SaveCacheInfo(map[string]*_storage.CacheInfoItem{
+		server.URL + "/atom": {
+			URL:        server.URL + "/atom",
+			LastFetch:  time.Unix(defaultCurrentTime.Unix(), 0),
+			ETag:       "etag",
+			FetchAfter: time.Unix(defaultCurrentTime.Unix()+300, 0),
+		},
+	})
+
+	feed := internal.NewTerminalFeed(timeMock, printer, storage)
+
+	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
+	assert.NoError(t, err)
+
+	os.Args = []string{"cleed", "-C"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `Atom Feed      Item 2
+1594 days ago  https://atom-feed.com/item-2/
+
+Atom Feed      Item 1
+18 hours ago   https://atom-feed.com/item-1/
+
+`, out.String())
+}
+
+func Test_Feed_HideFutureItems(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	timeMock := mocks.NewMockTime(ctrl)
+	timeMock.EXPECT().Now().Return(defaultCurrentTime).AnyTimes()
+
+	out := new(bytes.Buffer)
+	printer := internal.NewPrinter(nil, out, out)
+	storage := _storage.NewLocalStorage("cleed_test", timeMock)
+	defer localStorageCleanup(t, storage)
+	storage.Init("0.1.0")
+
+	configDir, err := os.UserConfigDir()
+	if err != nil {
+		t.Fatal(err)
+	}
+	listsDir := path.Join(configDir, "cleed_test", "lists")
+	err = os.MkdirAll(listsDir, 0700)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	config, err := storage.LoadConfig()
+	if err != nil {
+		t.Fatal(err)
+	}
+	config.HideFutureItems = true
+	config.Summary = 1
+	err = storage.SaveConfig()
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	items := []*FeedItem{
+		{
+			Title:     "Item 1",
+			Link:      "https://rss-feed.com/item-1/",
+			Published: defaultCurrentTime.Add(-time.Hour).Format(time.RFC3339),
+		},
+		{
+			Title:     "Item 2",
+			Link:      "https://rss-feed.com/item-2/",
+			Published: defaultCurrentTime.Add(time.Hour).Format(time.RFC3339),
+		},
+	}
+	rss := createRSS(items)
+	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		w.Write([]byte(rss))
+	}))
+	defer server.Close()
+
+	err = os.WriteFile(path.Join(listsDir, "default"),
+		fmt.Appendf(nil, "%d %s\n",
+			defaultCurrentTime.Unix(), server.URL+"/rss",
+		), 0600)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	feed := internal.NewTerminalFeed(timeMock, printer, storage)
+
+	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
+	assert.NoError(t, err)
+
+	os.Args = []string{"cleed"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `RSS Feed    • Item 1
+1 hour ago  https://rss-feed.com/item-1/
+
+Displayed 1 item from 1 feed (0 cached, 1 fetched) with 2 items in 0.00s
+`, out.String())
+}
+
 func Test_Feed_Search(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -189,16 +350,14 @@ func Test_Feed_Search(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -219,6 +378,139 @@ RSS Feed        • Keyword 1
 `, out.String())
 }
 
+func Test_Feed_SearchRegexp(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	timeMock := mocks.NewMockTime(ctrl)
+	timeMock.EXPECT().Now().Return(defaultCurrentTime).AnyTimes()
+
+	out := new(bytes.Buffer)
+	printer := internal.NewPrinter(nil, out, out)
+	storage := _storage.NewLocalStorage("cleed_test", timeMock)
+	defer localStorageCleanup(t, storage)
+
+	configDir, err := os.UserConfigDir()
+	if err != nil {
+		t.Fatal(err)
+	}
+	listsDir := path.Join(configDir, "cleed_test", "lists")
+	err = os.MkdirAll(listsDir, 0700)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	items := []*FeedItem{
+		{
+			Title:     "Keyword 1",
+			Link:      "https://rss-feed.com/item-1/",
+			Published: "Wed, 31 Dec 2023 23:45:00 GMT",
+		},
+		{
+			Title:     "keywords",
+			Link:      "https://rss-feed.com/item-1/",
+			Published: "Wed, 31 Dec 2023 23:45:00 GMT",
+		},
+		{
+			Title:     "keywordxaxa",
+			Link:      "https://rss-feed.com/item-1/",
+			Published: "Wed, 31 Dec 2023 23:45:00 GMT",
+		},
+		{
+			Title:     "zzzz",
+			Link:      "https://rss-feed.com/item-1/",
+			Published: "Wed, 31 Dec 2023 23:45:00 GMT",
+		},
+		{
+			Title:     "zzsdd",
+			Link:      "https://rss-feed.com/item-1/",
+			Published: "Wed, 31 Dec 2023 23:45:00 GMT",
+		},
+	}
+	rss := createRSS(items)
+	server := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
+		w.Write([]byte(rss))
+	}))
+	defer server.Close()
+
+	err = os.WriteFile(path.Join(listsDir, "default"),
+		fmt.Appendf(nil, "%d %s\n",
+			defaultCurrentTime.Unix(), server.URL+"/rss",
+		), 0600)
+	if err != nil {
+		t.Fatal(err)
+	}
+
+	feed := internal.NewTerminalFeed(timeMock, printer, storage)
+
+	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
+	assert.NoError(t, err)
+
+	os.Args = []string{"cleed", "--searchr", "zz"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `RSS Feed        • zzsdd
+15 minutes ago  https://rss-feed.com/item-1/
+
+RSS Feed        • zzzz
+15 minutes ago  https://rss-feed.com/item-1/
+
+`, out.String())
+
+	out.Reset()
+	os.Args = []string{"cleed", "--searchr", "keyword"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `RSS Feed        keywordxaxa
+15 minutes ago  https://rss-feed.com/item-1/
+
+RSS Feed        keywords
+15 minutes ago  https://rss-feed.com/item-1/
+
+`, out.String())
+
+	out.Reset()
+	os.Args = []string{"cleed", "--searchr", "(?i)keyword"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `RSS Feed        keywordxaxa
+15 minutes ago  https://rss-feed.com/item-1/
+
+RSS Feed        keywords
+15 minutes ago  https://rss-feed.com/item-1/
+
+RSS Feed        Keyword 1
+15 minutes ago  https://rss-feed.com/item-1/
+
+`, out.String())
+
+	out.Reset()
+	os.Args = []string{"cleed", "--searchr", "^keyword"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `RSS Feed        keywordxaxa
+15 minutes ago  https://rss-feed.com/item-1/
+
+RSS Feed        keywords
+15 minutes ago  https://rss-feed.com/item-1/
+
+`, out.String())
+
+	out.Reset()
+	os.Args = []string{"cleed", "--searchr", "s$"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, `RSS Feed        keywords
+15 minutes ago  https://rss-feed.com/item-1/
+
+`, out.String())
+}
+
 func Test_Feed_With_Summary(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -265,24 +557,21 @@ func Test_Feed_With_Summary(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 	err = os.WriteFile(path.Join(listsDir, "test"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -375,24 +664,21 @@ func Test_Feed_Specific_List(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 	err = os.WriteFile(path.Join(listsDir, "test"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -438,9 +724,8 @@ func Test_Feed_NotModified(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL,
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -462,7 +747,6 @@ func Test_Feed_NotModified(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -509,16 +793,14 @@ func Test_Feed_CacheControl(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL,
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -575,9 +857,8 @@ func Test_Feed_RetryAfter(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL,
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -599,7 +880,6 @@ func Test_Feed_RetryAfter(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -650,9 +930,8 @@ func Test_Feed_FetchAfter_Load_From_Cache(t *testing.T) {
 	}
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), "https://example.com",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -683,7 +962,6 @@ func Test_Feed_FetchAfter_Load_From_Cache(t *testing.T) {
 	})
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -729,9 +1007,8 @@ func Test_Feed_Limit(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n",
+		fmt.Appendf(nil, "%d %s\n",
 			defaultCurrentTime.Unix(), server.URL,
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -753,7 +1030,6 @@ func Test_Feed_Limit(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -796,10 +1072,9 @@ func Test_Feed_Since_Period(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n%d %s\n",
+		fmt.Appendf(nil, "%d %s\n%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -824,7 +1099,6 @@ func Test_Feed_Since_Period(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -870,10 +1144,9 @@ func Test_Feed_Since_Date(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n%d %s\n",
+		fmt.Appendf(nil, "%d %s\n%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -898,7 +1171,6 @@ func Test_Feed_Since_Date(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -944,10 +1216,9 @@ func Test_Feed_Since_Last(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n%d %s\n",
+		fmt.Appendf(nil, "%d %s\n%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -989,7 +1260,6 @@ func Test_Feed_Since_Last(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -1038,10 +1308,9 @@ func Test_Feed_Since_Last_With_Summary(t *testing.T) {
 	defer server.Close()
 
 	err = os.WriteFile(path.Join(listsDir, "default"),
-		[]byte(fmt.Sprintf("%d %s\n%d %s\n",
+		fmt.Appendf(nil, "%d %s\n%d %s\n",
 			defaultCurrentTime.Unix(), server.URL+"/rss",
 			defaultCurrentTime.Unix(), server.URL+"/atom",
-		),
 		), 0600)
 	if err != nil {
 		t.Fatal(err)
@@ -1084,7 +1353,6 @@ func Test_Feed_Since_Last_With_Summary(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -1124,7 +1392,6 @@ func Test_Config_Dir(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -1154,7 +1421,6 @@ func Test_Cache_Dir(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
@@ -1166,6 +1432,44 @@ func Test_Cache_Dir(t *testing.T) {
 	assert.Equal(t, path.Join(cacheDir, "cleed_test")+"\n", out.String())
 }
 
+func Test_Config_And_Cache_Dir_With_Custom_Data_Path(t *testing.T) {
+	ctrl := gomock.NewController(t)
+	defer ctrl.Finish()
+
+	timeMock := mocks.NewMockTime(ctrl)
+	timeMock.EXPECT().Now().Return(defaultCurrentTime).AnyTimes()
+
+	customPath := path.Join(os.TempDir(), "cleed_custom_path_test")
+	os.Setenv("CLEED_DATA_PATH", customPath)
+	defer os.Unsetenv("CLEED_DATA_PATH")
+	defer os.RemoveAll(customPath)
+
+	out := new(bytes.Buffer)
+	printer := internal.NewPrinter(nil, out, out)
+	storage := _storage.NewLocalStorage("cleed_test", timeMock)
+	defer localStorageCleanup(t, storage)
+
+	feed := internal.NewTerminalFeed(timeMock, printer, storage)
+
+	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
+	assert.NoError(t, err)
+
+	os.Args = []string{"cleed", "--config-path"}
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, path.Join(customPath, "config")+"\n", out.String())
+
+	root, err = NewRoot("0.1.0", timeMock, printer, storage, feed)
+	assert.NoError(t, err)
+	os.Args = []string{"cleed", "--cache-path"}
+	out.Reset()
+
+	err = root.Cmd.Execute()
+	assert.NoError(t, err)
+	assert.Equal(t, path.Join(customPath, "cache")+"\n", out.String())
+}
+
 func Test_Cache_Info(t *testing.T) {
 	ctrl := gomock.NewController(t)
 	defer ctrl.Finish()
@@ -1200,7 +1504,6 @@ func Test_Cache_Info(t *testing.T) {
 	}
 
 	feed := internal.NewTerminalFeed(timeMock, printer, storage)
-	feed.SetAgent("cleed/test")
 
 	root, err := NewRoot("0.1.0", timeMock, printer, storage, feed)
 	assert.NoError(t, err)
