@@ -1,15 +1,12 @@
 package internal
 
 import (
-	"bufio"
 	"compress/gzip"
-	"context"
-	"encoding/xml"
 	"fmt"
 	"io"
 	"net/http"
 	"net/url"
-	"os"
+	"regexp"
 	"slices"
 	"strconv"
 	"strings"
@@ -21,25 +18,29 @@ import (
 	"github.com/mmcdole/gofeed"
 	"github.com/radulucut/cleed/internal/storage"
 	"github.com/radulucut/cleed/internal/utils"
+	"golang.org/x/net/proxy"
+	miniflux "miniflux.app/v2/client"
 )
 
 type TerminalFeed struct {
-	time    utils.Time
-	printer *Printer
-	storage *storage.LocalStorage
-	http    *http.Client
-	parser  *gofeed.Parser
+	time     utils.Time
+	printer  *Printer
+	storage  *storage.LocalStorage
+	http     *http.Client
+	parser   *gofeed.Parser
+	miniflux *miniflux.Client
 
-	agent string
+	version                  string
+	defaultExploreRepository string
 }
 
 func NewTerminalFeed(
-	time utils.Time,
+	_time utils.Time,
 	printer *Printer,
 	storage *storage.LocalStorage,
 ) *TerminalFeed {
 	return &TerminalFeed{
-		time:    time,
+		time:    _time,
 		printer: printer,
 		storage: storage,
 
@@ -48,116 +49,6 @@ func NewTerminalFeed(
 	}
 }
 
-func (f *TerminalFeed) SetAgent(agent string) {
-	f.agent = agent
-}
-
-func (f *TerminalFeed) DisplayConfig() error {
-	config, err := f.storage.LoadConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to load config: " + err.Error())
-	}
-	styling := "default"
-	if config.Styling == 0 {
-		styling = "enabled"
-	} else if config.Styling == 1 {
-		styling = "disabled"
-	}
-	f.printer.Println("Styling:", styling)
-	f.printer.Print("Color map:")
-	for k, v := range config.ColorMap {
-		f.printer.Printf(" %d:%d", k, v)
-	}
-	f.printer.Println()
-	summary := "disabled"
-	if config.Summary == 1 {
-		summary = "enabled"
-	}
-	f.printer.Println("Summary:", summary)
-	return nil
-}
-
-func (f *TerminalFeed) SetStyling(v uint8) error {
-	config, err := f.storage.LoadConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to load config: " + err.Error())
-	}
-	if v > 2 {
-		return utils.NewInternalError("invalid value for styling")
-	}
-	config.Styling = v
-	err = f.storage.SaveConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to save config: " + err.Error())
-	}
-	f.printer.Println("styling was updated")
-	return nil
-}
-
-func (f *TerminalFeed) SetSummary(v uint8) error {
-	config, err := f.storage.LoadConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to load config: " + err.Error())
-	}
-	if v > 1 {
-		return utils.NewInternalError("invalid value for summary")
-	}
-	config.Summary = v
-	err = f.storage.SaveConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to save config: " + err.Error())
-	}
-	f.printer.Println("summary was updated")
-	return nil
-}
-
-func (f *TerminalFeed) UpdateColorMap(mappings string) error {
-	config, err := f.storage.LoadConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to load config: " + err.Error())
-	}
-	if mappings == "" {
-		config.ColorMap = make(map[uint8]uint8)
-	} else {
-		colors := strings.Split(mappings, ",")
-		for i := range colors {
-			parts := strings.Split(colors[i], ":")
-			if len(parts) == 0 {
-				return utils.NewInternalError("failed to parse color mapping: " + colors[i])
-			}
-			left, err := strconv.Atoi(parts[0])
-			if err != nil {
-				return utils.NewInternalError("failed to parse color mapping: " + parts[0])
-			}
-			if len(parts) == 1 || parts[1] == "" {
-				delete(config.ColorMap, uint8(left))
-			} else {
-				right, err := strconv.Atoi(parts[1])
-				if err != nil {
-					return utils.NewInternalError("failed to parse color mapping: " + parts[1])
-				}
-				config.ColorMap[uint8(left)] = uint8(right)
-			}
-		}
-	}
-	err = f.storage.SaveConfig()
-	if err != nil {
-		return utils.NewInternalError("failed to save config: " + err.Error())
-	}
-	f.printer.Println("color map updated")
-	return nil
-}
-
-func (f *TerminalFeed) DisplayColorRange() {
-	styling := f.printer.GetStyling()
-	f.printer.SetStyling(true)
-	for i := 0; i < 256; i++ {
-		f.printer.Print(f.printer.ColorForeground(fmt.Sprintf("%d ", i), uint8(i)))
-	}
-	f.printer.Println()
-	f.printer.SetStyling(styling)
-}
-
 func (f *TerminalFeed) Follow(urls []string, list string) error {
 	if len(urls) == 0 {
 		return utils.NewInternalError("please provide at least one URL")
@@ -247,114 +138,6 @@ func (f *TerminalFeed) RemoveList(list string) error {
 	return nil
 }
 
-func (f *TerminalFeed) ImportFromFile(path, list string) error {
-	fi, err := os.Open(path)
-	if err != nil {
-		return utils.NewInternalError("failed to open file: " + err.Error())
-	}
-	defer fi.Close()
-	urls := make([]string, 0)
-	scanner := bufio.NewScanner(fi)
-	for scanner.Scan() {
-		line := strings.TrimSpace(scanner.Text())
-		if line == "" {
-			continue
-		}
-		if strings.HasPrefix(line, "#") {
-			continue
-		}
-		urls = append(urls, line)
-	}
-	err = f.storage.AddToList(urls, list)
-	if err != nil {
-		return utils.NewInternalError("failed to save feeds: " + err.Error())
-	}
-	f.printer.Printf("added %s to list: %s\n", utils.Pluralize(int64(len(urls)), "feed"), list)
-	return nil
-}
-
-func (f *TerminalFeed) ExportToFile(path, list string) error {
-	feeds, err := f.storage.GetFeedsFromList(list)
-	if err != nil {
-		return utils.NewInternalError("failed to list feeds: " + err.Error())
-	}
-	if len(feeds) == 0 {
-		f.printer.Println("no feeds to export")
-		return nil
-	}
-	fo, err := os.Create(path)
-	if err != nil {
-		return utils.NewInternalError("failed to create file: " + err.Error())
-	}
-	defer fo.Close()
-	for i := range feeds {
-		_, err = fo.WriteString(feeds[i].Address + "\n")
-		if err != nil {
-			return utils.NewInternalError("failed to write to file: " + err.Error())
-		}
-	}
-	f.printer.Printf("exported %s to %s\n", utils.Pluralize(int64(len(feeds)), "feed"), path)
-	return nil
-}
-
-func (f *TerminalFeed) ImportFromOPML(path, list string) error {
-	b, err := os.ReadFile(path)
-	if err != nil {
-		return utils.NewInternalError("failed to read file: " + err.Error())
-	}
-	opml := &utils.OPML{}
-	err = xml.Unmarshal(b, opml)
-	if err != nil {
-		return utils.NewInternalError("failed to parse OPML: " + err.Error())
-	}
-	urls := make([]string, 0, len(opml.Body.Oultines))
-	if len(opml.Body.Oultines) == 0 {
-		return utils.NewInternalError("no feeds found in OPML")
-	}
-	outlines := opml.Body.Oultines[0].Outlines
-	for _, o := range outlines {
-		urls = append(urls, o.XMLURL)
-	}
-	err = f.storage.AddToList(urls, list)
-	if err != nil {
-		return utils.NewInternalError("failed to save feeds: " + err.Error())
-	}
-	f.printer.Printf("added %s to list: %s\n", utils.Pluralize(int64(len(urls)), "feed"), list)
-	return nil
-}
-
-func (f *TerminalFeed) ExportToOPML(path, list string) error {
-	feeds, err := f.storage.GetFeedsFromList(list)
-	if err != nil {
-		return utils.NewInternalError("failed to list feeds: " + err.Error())
-	}
-	if len(feeds) == 0 {
-		f.printer.Println("no feeds to export")
-		return nil
-	}
-	fo, err := os.Create(path)
-	if err != nil {
-		return utils.NewInternalError("failed to create file: " + err.Error())
-	}
-	defer fo.Close()
-	fmt.Fprintf(fo, `%s<opml version="1.0">
-  <head>
-    <title>%s</title>
-  </head>
-  <body>
-	<outline text="%s">
-`, xml.Header, list, list)
-	for i := range feeds {
-		fmt.Fprintf(fo, `      <outline xmlUrl="%s"/>
-`, feeds[i].Address)
-	}
-	fmt.Fprint(fo, `	</outline>
-  </body>
-</opml>`)
-	f.printer.Printf("exported %s to %s\n", utils.Pluralize(int64(len(feeds)), "feed"), path)
-	return nil
-}
-
 func (f *TerminalFeed) ShowConfigPath() error {
 	path, err := f.storage.JoinConfigDir("")
 	if err != nil {
@@ -387,13 +170,7 @@ func (f *TerminalFeed) ShowCacheInfo() error {
 	f.printer.Print(runewidth.FillRight("URL", cellMax[0]))
 	f.printer.Println("  Last fetch           Fetch after")
 	slices.SortFunc(items, func(a, b *storage.CacheInfoItem) int {
-		if a.URL < b.URL {
-			return -1
-		}
-		if a.URL > b.URL {
-			return 1
-		}
-		return 0
+		return strings.Compare(a.URL, b.URL)
 	})
 	for i := range items {
 		f.printer.Print(runewidth.FillRight(items[i].URL, cellMax[0]))
@@ -403,10 +180,13 @@ func (f *TerminalFeed) ShowCacheInfo() error {
 }
 
 type FeedOptions struct {
-	List  string
-	Query [][]rune
-	Limit int
-	Since time.Time
+	List       string
+	Query      [][]rune
+	Regexp     *regexp.Regexp
+	Limit      int
+	Since      time.Time
+	Proxy      *url.URL
+	CachedOnly bool
 }
 
 func (f *TerminalFeed) Search(query string, opts *FeedOptions) error {
@@ -438,6 +218,38 @@ func (f *TerminalFeed) Search(query string, opts *FeedOptions) error {
 	return nil
 }
 
+func (f *TerminalFeed) SearchRegexp(query string, opts *FeedOptions) error {
+	summary := &RunSummary{
+		Start: f.time.Now(),
+	}
+	config, err := f.storage.LoadConfig()
+	if err != nil {
+		return utils.NewInternalError("failed to load config: " + err.Error())
+	}
+	opts.Regexp, err = regexp.Compile(query)
+	if err != nil {
+		return utils.NewInternalError("failed to compile expression: " + err.Error())
+	}
+	items, err := f.processFeeds(opts, config, summary)
+	if err != nil {
+		return err
+	}
+	slices.SortFunc(items, func(a, b *FeedItem) int {
+		if a.Item.PublishedParsed == nil || b.Item.PublishedParsed == nil {
+			return 0
+		}
+		if a.Item.PublishedParsed.After(*b.Item.PublishedParsed) {
+			return -1
+		}
+		if a.Item.PublishedParsed.Before(*b.Item.PublishedParsed) {
+			return 1
+		}
+		return 0
+	})
+	f.outputItems(items, config, summary, opts)
+	return nil
+}
+
 type FeedItem struct {
 	Feed              *gofeed.Feed
 	Item              *gofeed.Item
@@ -515,6 +327,10 @@ func (f *TerminalFeed) outputItems(
 		if fi.IsNew {
 			newMark = f.printer.ColorForeground("• ", highlightColor)
 		}
+		if strings.HasPrefix(fi.Item.Link, "/") {
+			baseUrl := strings.TrimSuffix(fi.Feed.Link, "/")
+			fi.Item.Link = baseUrl + fi.Item.Link
+		}
 		f.printer.Print(
 			f.printer.ColorForeground(runewidth.FillRight(runewidth.Truncate(fi.Feed.Title, cellMax[0], "..."), cellMax[0]), fi.FeedColor),
 			"  ",
@@ -544,7 +360,11 @@ func (f *TerminalFeed) printSummary(s *RunSummary) {
 }
 
 func (f *TerminalFeed) processFeeds(opts *FeedOptions, config *storage.Config, summary *RunSummary) ([]*FeedItem, error) {
-	var err error
+	f.http.Timeout = time.Duration(config.Timeout) * time.Second
+	err := f.setProxy(opts)
+	if err != nil {
+		return nil, err
+	}
 	lists := make([]string, 0)
 	if opts.List != "" {
 		lists = append(lists, opts.List)
@@ -568,9 +388,11 @@ func (f *TerminalFeed) processFeeds(opts *FeedOptions, config *storage.Config, s
 	}
 	mx := sync.Mutex{}
 	wg := sync.WaitGroup{}
+	sem := make(chan struct{}, config.BatchSize)
 	items := make([]*FeedItem, 0)
 	feedColorMap := make(map[string]uint8)
 	for url := range feeds {
+		sem <- struct{}{}
 		ci := cacheInfo[url]
 		if ci == nil {
 			ci = &storage.CacheInfoItem{
@@ -583,7 +405,21 @@ func (f *TerminalFeed) processFeeds(opts *FeedOptions, config *storage.Config, s
 		wg.Add(1)
 		go func(ci *storage.CacheInfoItem) {
 			defer wg.Done()
-			res, err := f.fetchFeed(ci)
+			defer func() {
+				<-sem
+			}()
+			if opts.CachedOnly {
+				feed, err := f.parseFeed(url)
+				if err != nil {
+					return
+				}
+				mx.Lock()
+				defer mx.Unlock()
+				items = f.processFeedItems(feed, items, config, opts, summary, feedColorMap, ci)
+				summary.FeedsCached++
+				return
+			}
+			res, err := f.fetchFeed(ci, config)
 			if err != nil {
 				f.printer.ErrPrintf("failed to fetch feed: %s: %v\n", ci.URL, err)
 				return
@@ -595,34 +431,7 @@ func (f *TerminalFeed) processFeeds(opts *FeedOptions, config *storage.Config, s
 			}
 			mx.Lock()
 			defer mx.Unlock()
-			summary.ItemsCount += len(feed.Items)
-			color, ok := feedColorMap[feed.Title]
-			if !ok {
-				color = mapColor(uint8(len(feedColorMap)%256), config)
-				feedColorMap[feed.Title] = color
-			}
-			for _, feedItem := range feed.Items {
-				if feedItem.PublishedParsed == nil {
-					feedItem.PublishedParsed = &time.Time{}
-				}
-				if !opts.Since.IsZero() && feedItem.PublishedParsed.Before(opts.Since) {
-					continue
-				}
-				score := 0
-				if len(opts.Query) > 0 {
-					score = utils.Score(opts.Query, f.tokenizeItem(feedItem))
-				}
-				if score == -1 {
-					continue
-				}
-				items = append(items, &FeedItem{
-					Feed:      feed,
-					Item:      feedItem,
-					FeedColor: color,
-					IsNew:     feedItem.PublishedParsed.After(ci.LastFetch),
-					Score:     score,
-				})
-			}
+			items = f.processFeedItems(feed, items, config, opts, summary, feedColorMap, ci)
 			if res.Changed {
 				ci.ETag = res.ETag
 				ci.LastFetch = f.time.Now()
@@ -660,25 +469,74 @@ func (f *TerminalFeed) parseFeed(url string) (*gofeed.Feed, error) {
 	return f.parser.Parse(fc)
 }
 
+func (f *TerminalFeed) processFeedItems(
+	feed *gofeed.Feed,
+	items []*FeedItem,
+	config *storage.Config,
+	opts *FeedOptions,
+	summary *RunSummary,
+	feedColorMap map[string]uint8,
+	ci *storage.CacheInfoItem,
+) []*FeedItem {
+	summary.ItemsCount += len(feed.Items)
+	color, ok := feedColorMap[feed.Title]
+	if !ok {
+		color = mapColor(uint8(len(feedColorMap)%256), config)
+		feedColorMap[feed.Title] = color
+	}
+	currentTime := f.time.Now()
+	for _, feedItem := range feed.Items {
+		if feedItem.PublishedParsed == nil {
+			feedItem.PublishedParsed = &time.Time{}
+		}
+		if !opts.Since.IsZero() && feedItem.PublishedParsed.Before(opts.Since) {
+			continue
+		}
+		if config.HideFutureItems && feedItem.PublishedParsed.After(currentTime) {
+			continue
+		}
+		// default search
+		score := 0
+		if len(opts.Query) > 0 {
+			score = utils.Score(opts.Query, f.tokenizeItem(feedItem))
+			if score == -1 {
+				continue
+			}
+		}
+		// regex search
+		if opts.Regexp != nil && !opts.Regexp.MatchString(feedItem.Title) {
+			continue
+		}
+		items = append(items, &FeedItem{
+			Feed:      feed,
+			Item:      feedItem,
+			FeedColor: color,
+			IsNew:     feedItem.PublishedParsed.After(ci.LastFetch),
+			Score:     score,
+		})
+	}
+	return items
+}
+
 type FetchResult struct {
 	Changed    bool
 	ETag       string
 	FetchAfter time.Time
 }
 
-func (f *TerminalFeed) fetchFeed(feed *storage.CacheInfoItem) (*FetchResult, error) {
+func (f *TerminalFeed) fetchFeed(feed *storage.CacheInfoItem, config *storage.Config) (*FetchResult, error) {
 	if feed.FetchAfter.After(f.time.Now()) {
 		return &FetchResult{
 			Changed: false,
 		}, nil
 	}
-	ctx, cancel := context.WithTimeout(context.Background(), 30*time.Second)
-	defer cancel()
-	req, err := http.NewRequestWithContext(ctx, "GET", feed.URL, nil)
+	req, err := http.NewRequest("GET", feed.URL, nil)
 	if err != nil {
 		return nil, utils.NewInternalError(fmt.Sprintf("failed to create request: %v", err))
 	}
-	req.Header.Set("User-Agent", f.agent)
+	if config.UserAgent != "-" {
+		req.Header.Set("User-Agent", config.UserAgent)
+	}
 	if feed.ETag != "" {
 		req.Header.Set("If-None-Match", feed.ETag)
 	}
@@ -740,6 +598,36 @@ func (f *TerminalFeed) parseRetryAfter(retryAfter string) time.Time {
 	return f.time.Now().Add(5 * time.Minute)
 }
 
+func (f *TerminalFeed) setProxy(opts *FeedOptions) error {
+	if opts.Proxy == nil {
+		return nil
+	}
+	var transport *http.Transport
+	if strings.HasPrefix(strings.ToLower(opts.Proxy.Scheme), "socks5") {
+		var auth *proxy.Auth
+		if opts.Proxy.User != nil {
+			password, _ := opts.Proxy.User.Password()
+			auth = &proxy.Auth{
+				User:     opts.Proxy.User.Username(),
+				Password: password,
+			}
+		}
+		dialer, err := proxy.SOCKS5("tcp", opts.Proxy.Host, auth, proxy.Direct)
+		if err != nil {
+			return utils.NewInternalError("failed to create SOCKS5 dialer: " + err.Error())
+		}
+		transport = &http.Transport{
+			Dial: dialer.Dial,
+		}
+	} else {
+		transport = &http.Transport{
+			Proxy: http.ProxyURL(opts.Proxy),
+		}
+	}
+	f.http.Transport = transport
+	return nil
+}
+
 func parseMaxAge(cacheControl string) time.Duration {
 	if cacheControl == "" {
 		return 60 * time.Second
