@@ -11,11 +11,19 @@ const (
 )
 
 type Config struct {
-	Version  string          `json:"version"`
-	LastRun  time.Time       `json:"lastRun"`
-	Styling  uint8           `json:"styling"` // 0: default, 1: enabled, 2: disabled
-	Summary  uint8           `json:"summary"` // 0: disabled, 1: enabled
-	ColorMap map[uint8]uint8 `json:"colorMap"`
+	Version string `json:"version"`
+
+	UserAgent string `json:"userAgent"`
+	Timeout   uint   `json:"timeout"`   // in seconds
+	BatchSize uint   `json:"batchSize"` // number of feeds to fetch in a batch
+
+	LastRun         time.Time       `json:"lastRun"`
+	Styling         uint8           `json:"styling"` // 0: default, 1: enabled, 2: disabled
+	Summary         uint8           `json:"summary"` // 0: disabled, 1: enabled
+	ColorMap        map[uint8]uint8 `json:"colorMap"`
+	HideFutureItems bool            `json:"hideFutureItems"`
+
+	MinifluxToken string `json:"minifluxToken"`
 }
 
 func (s *LocalStorage) LoadConfig() (*Config, error) {
@@ -38,6 +46,12 @@ func (s *LocalStorage) LoadConfig() (*Config, error) {
 	if s.config.ColorMap == nil {
 		s.config.ColorMap = make(map[uint8]uint8)
 	}
+	if s.config.BatchSize == 0 {
+		s.config.BatchSize = 100
+	}
+	if s.config.Timeout == 0 {
+		s.config.Timeout = 30
+	}
 	return s.config, nil
 }
 
